Learn R Programming

CepLDA (version 1.0.0)

lperd.mtm: Multitaper Log-Periodogram

Description

Obtain multivariate log-periodogram. Not often used by itself, but is used as part of cep.mtm.

Usage

lperd.mtm(x,nw,k)

Arguments

x
N by n matrix containing n training time series each with length N.
nw
Width of tapers used in multitaper spectral estimation.
k
Number of tapers used in multitaper spectral estimation.

Value

freq
Fourier frequencies from 0 to 1.
lspec
Log-periodogram.
spec
Periodigram on the natural scale.

References

Krafty, RT (2016) Discriminant Analysis of Time Series in the Presence of Within-Group Spectral Variability. Journal of Time series analysis

See Also

cep.mtm, cep.lda